@@ -9,6 +9,7 @@ from . import (
     flac3d,
     gmsh,
     h5m,
+    hmf,
     mdpa,
     med,
     medit,
@@ -44,6 +45,7 @@ __all__ = [
     "flac3d",
     "gmsh",
     "h5m",
+    "hmf",
     "mdpa",
     "med",
     "medit",
