@@ -16,11 +16,11 @@ def ascii(argv=None):
     fmt = args.input_format or _filetype_from_path(pathlib.Path(args.infile))
 
     size = os.stat(args.infile).st_size
-    print("File size before: {:.2f} MB".format(size / 1024 ** 2))
+    print(f"File size before: {size / 1024 ** 2:.2f} MB")
     mesh = read(args.infile, file_format=args.input_format)
 
     # # Some converters (like VTK) require `points` to be contiguous.
-    # mesh.points = numpy.ascontiguousarray(mesh.points)
+    # mesh.points = np.ascontiguousarray(mesh.points)
 
     # write it out
     if fmt == "ansys":
@@ -42,11 +42,11 @@ def ascii(argv=None):
     elif fmt == "xdmf":
         xdmf.write(args.infile, mesh, data_format="XML")
     else:
-        print("Don't know how to convert {} to ASCII format.".format(args.infile))
+        print(f"Don't know how to convert {args.infile} to ASCII format.")
         exit(1)
 
     size = os.stat(args.infile).st_size
-    print("File size after:  {:.2f} MB".format(size / 1024 ** 2))
+    print(f"File size after: {size / 1024 ** 2:.2f} MB")
 
 
 def _get_parser():
