@@ -1,6 +1,6 @@
 from xml.etree import ElementTree as ET
 
-import numpy
+import numpy as np
 
 # See <https://github.com/nschloe/meshio/wiki/Node-ordering-in-cells> for the node
 # ordering.
@@ -83,7 +83,7 @@ num_nodes_per_cell = {
     "tetra286": 286,
 }
 
-_geometric_dimension = {
+_topological_dimension = {
     "line": 1,
     "triangle": 2,
     "quad": 2,
@@ -151,12 +151,12 @@ _geometric_dimension = {
 
 
 def cell_data_from_raw(cells, cell_data_raw):
-    cs = numpy.cumsum([len(c[1]) for c in cells])[:-1]
-    return {name: numpy.split(d, cs) for name, d in cell_data_raw.items()}
+    cs = np.cumsum([len(c[1]) for c in cells])[:-1]
+    return {name: np.split(d, cs) for name, d in cell_data_raw.items()}
 
 
 def raw_from_cell_data(cell_data):
-    return {name: numpy.concatenate(value) for name, value in cell_data.items()}
+    return {name: np.concatenate(value) for name, value in cell_data.items()}
 
 
 def write_xml(filename, root):
@@ -229,6 +229,22 @@ vtk_to_meshio_type = {
     # 65: VTK_HIGHER_ORDER_WEDGE,
     # 66: VTK_HIGHER_ORDER_PYRAMID,
     # 67: VTK_HIGHER_ORDER_HEXAHEDRON,
+    # Arbitrary order Lagrange elements
+    68: "VTK_LAGRANGE_CURVE",
+    69: "VTK_LAGRANGE_TRIANGLE",
+    70: "VTK_LAGRANGE_QUADRILATERAL",
+    71: "VTK_LAGRANGE_TETRAHEDRON",
+    72: "VTK_LAGRANGE_HEXAHEDRON",
+    73: "VTK_LAGRANGE_WEDGE",
+    74: "VTK_LAGRANGE_PYRAMID",
+    # Arbitrary order Bezier elements
+    75: "VTK_BEZIER_CURVE",
+    76: "VTK_BEZIER_TRIANGLE",
+    77: "VTK_BEZIER_QUADRILATERAL",
+    78: "VTK_BEZIER_TETRAHEDRON",
+    79: "VTK_BEZIER_HEXAHEDRON",
+    80: "VTK_BEZIER_WEDGE",
+    81: "VTK_BEZIER_PYRAMID",
 }
 meshio_to_vtk_type = {v: k for k, v in vtk_to_meshio_type.items()}
 
@@ -241,13 +257,13 @@ def _vtk_to_meshio_order(vtk_type, numnodes, dtype=int):
     # [1] http://gmsh.info/doc/texinfo/gmsh.html#Node-ordering
     # [2] https://vtk.org/doc/nightly/html/classvtkWedge.html
     if vtk_type == 13:
-        return numpy.array([0, 2, 1, 3, 5, 4], dtype=dtype)
+        return np.array([0, 2, 1, 3, 5, 4], dtype=dtype)
     else:
-        return numpy.arange(0, numnodes, dtype=dtype)
+        return np.arange(0, numnodes, dtype=dtype)
 
 
 def _meshio_to_vtk_order(meshio_type, numnodes, dtype=int):
     if meshio_type == "wedge":
-        return numpy.array([0, 2, 1, 3, 5, 4], dtype=dtype)
+        return np.array([0, 2, 1, 3, 5, 4], dtype=dtype)
     else:
-        return numpy.arange(0, numnodes, dtype=dtype)
+        return np.arange(0, numnodes, dtype=dtype)
