@@ -5,7 +5,7 @@ I/O for h5m, cf.
 import logging
 from datetime import datetime
 
-import numpy
+import numpy as np
 
 from .. import __about__
 from .._helpers import register
@@ -21,6 +21,8 @@ def read(filename):
     """Reads H5M files, cf.
     https://trac.mcs.anl.gov/projects/ITAPS/wiki/MOAB/h5m.
     """
+    import h5py
+
     f = h5py.File(filename, "r")
     dset = f["tstt"]
 
@@ -81,7 +83,7 @@ def read(filename):
     #     # create the sets
     #     for key, value in sets_tags.items():
     #         mod_key = 'set::' + key
-    #         cell_data[mod_key] = numpy.empty(len(cells), dtype=int)
+    #         cell_data[mod_key] = np.empty(len(cells), dtype=int)
     #         end = 0
     #         for k, row in enumerate(sets_list):
     #             bits = _int_to_bool_list(row[3])
@@ -117,6 +119,8 @@ def write(filename, mesh, add_global_ids=True, compression="gzip", compression_o
     """Writes H5M files, cf.
     https://trac.mcs.anl.gov/projects/ITAPS/wiki/MOAB/h5m.
     """
+    import h5py
+
     f = h5py.File(filename, "w")
 
     tstt = f.create_group("tstt")
@@ -144,7 +148,7 @@ def write(filename, mesh, add_global_ids=True, compression="gzip", compression_o
     # Copy to pd to avoid changing point_data. The items are not deep-copied.
     pd = mesh.point_data.copy()
     if "GLOBAL_ID" not in pd and add_global_ids:
-        pd["GLOBAL_ID"] = numpy.arange(1, len(mesh.points) + 1)
+        pd["GLOBAL_ID"] = np.arange(1, len(mesh.points) + 1)
 
     # add point data
     if pd:
@@ -162,7 +166,7 @@ def write(filename, mesh, add_global_ids=True, compression="gzip", compression_o
             # H5M doesn't accept n-x-k arrays as data; it wants an n-x-1
             # array with k-tuples as entries.
             n, k = data.shape
-            dtype = numpy.dtype((data.dtype, (k,)))
+            dtype = np.dtype((data.dtype, (k,)))
             dset = tags.create_dataset(
                 key,
                 (n,),
@@ -267,10 +271,4 @@ def write(filename, mesh, add_global_ids=True, compression="gzip", compression_o
     tstt.attrs.create("max_id", global_id, dtype="u8")
 
 
-try:
-    import h5py
-# Use ModuleNotFoundError when dropping support for Python 3.5
-except ImportError:
-    pass
-else:
-    register("h5m", [".h5m"], read, {"h5m": write})
+register("h5m", [".h5m"], read, {"h5m": write})
