@@ -7,7 +7,7 @@ The MDPA format is unsuitable for fast consumption, this is why:
 """
 import logging
 
-import numpy
+import numpy as np
 
 from .._common import num_nodes_per_cell, raw_from_cell_data
 from .._exceptions import ReadError, WriteError
@@ -90,8 +90,7 @@ local_dimension_types = {
 
 
 def read(filename):
-    """Reads a KratosMultiphysics mdpa file.
-    """
+    """Reads a KratosMultiphysics mdpa file."""
     # if (have_kratos is True): # TODO: Implement natively
     # pass
     # else:
@@ -116,7 +115,7 @@ def _read_nodes(f, is_ascii, data_size):
         num_nodes += 1
     f.seek(pos)
 
-    points = numpy.fromfile(f, count=num_nodes * 4, sep=" ").reshape((num_nodes, 4))
+    points = np.fromfile(f, count=num_nodes * 4, sep=" ").reshape((num_nodes, 4))
     # The first number is the index
     points = points[:, 1:]
 
@@ -162,7 +161,7 @@ def _read_cells(f, cells, is_ascii, cell_tags, environ=None):
         if len(cells) == 0 or t != cells[-1].type:
             cells.append(CellBlock(t, []))
         # Subtract one to account for the fact that python indices are 0-based.
-        cells[-1].data.append(numpy.array(data[-num_nodes_per_elem:]) - 1)
+        cells[-1].data.append(np.array(data[-num_nodes_per_elem:]) - 1)
 
         # Using the property id as tag
         if t not in cell_tags:
@@ -171,7 +170,7 @@ def _read_cells(f, cells, is_ascii, cell_tags, environ=None):
 
     # convert to numpy arrays
     for k, c in enumerate(cells):
-        cells[k] = CellBlock(c.type, numpy.array(c.data, dtype=int))
+        cells[k] = CellBlock(c.type, np.array(c.data, dtype=int))
 
     # Cannot convert cell_tags[key] to numpy array: There may be a
     # different number of tags for each cell.
@@ -195,10 +194,10 @@ def _prepare_cells(cells, cell_tags):
                 output_cell_tags[key]["gmsh:geometrical"].append(item[1])
             if len(item) > 2:
                 has_additional_tag_data = True
-        output_cell_tags[key]["gmsh:physical"] = numpy.array(
+        output_cell_tags[key]["gmsh:physical"] = np.array(
             output_cell_tags[key]["gmsh:physical"], dtype=int
         )
-        output_cell_tags[key]["gmsh:geometrical"] = numpy.array(
+        output_cell_tags[key]["gmsh:geometrical"] = np.array(
             output_cell_tags[key]["gmsh:geometrical"], dtype=int
         )
 
@@ -241,8 +240,6 @@ def _prepare_cells(cells, cell_tags):
             ],
         ]
 
-    cell_tags = output_cell_tags
-
     return has_additional_tag_data
 
 
@@ -266,14 +263,14 @@ def _read_data(f, tag, data_dict, data_size, is_ascii, environ=None):
     num_items = integer_tags[2]
 
     # Creating data
-    data = numpy.fromfile(f, count=num_items * (1 + num_components), sep=" ").reshape(
+    data = np.fromfile(f, count=num_items * (1 + num_components), sep=" ").reshape(
         (num_items, 1 + num_components)
     )
     # The first number is the index
     data = data[:, 1:]
 
     line = f.readline().decode("utf-8")
-    if line.strip() != "End {}".format(tag):
+    if line.strip() != f"End {tag}":
         raise ReadError()
 
     # The gmsh format cannot distingiush between data of shape (n,) and (n, 1).
@@ -421,7 +418,7 @@ def _write_elements_and_conditions(fh, cells, tag_data, binary=False, dimension=
             )
 
         # TODO: Add proper tag recognition in the future
-        fcd = numpy.empty((len(node_idcs), 0), dtype=numpy.int32)
+        fcd = np.empty((len(node_idcs), 0), dtype=np.int32)
 
         form = "{} " + str(fcd.shape[1]) + " {} {}\n"
         for k, c in enumerate(node_idcs):
@@ -474,8 +471,8 @@ def write(filename, mesh, float_fmt=".16e", binary=False):
             "mdpa requires 3D points, but 2D points given. "
             "Appending 0 third component."
         )
-        mesh.points = numpy.column_stack(
-            [mesh.points[:, 0], mesh.points[:, 1], numpy.zeros(mesh.points.shape[0])]
+        mesh.points = np.column_stack(
+            [mesh.points[:, 0], mesh.points[:, 1], np.zeros(mesh.points.shape[0])]
         )
 
     # Kratos cells are mostly ordered like VTK, with a few exceptions:
@@ -530,16 +527,13 @@ def write(filename, mesh, float_fmt=".16e", binary=False):
         # rest is actual cell data.
         tag_data = {}
         other_data = {}
-        for cell_type, a in mesh.cell_data.items():
-            tag_data[cell_type] = {}
-            other_data[cell_type] = {}
-            for key, data in a.items():
-                if key in ["gmsh:physical", "gmsh:geometrical"]:
-                    tag_data[cell_type][key] = data.astype(numpy.int32)
-                else:
-                    other_data[cell_type][key] = data
+        for key, data in mesh.cell_data.items():
+            if key in ["gmsh:physical", "gmsh:geometrical"]:
+                tag_data[key] = [entry.astype(np.int32) for entry in data]
+            else:
+                other_data[key] = data
 
-        # We identity which dimension are we
+        # identity dimension
         dimension = 2
         for c in cells:
             name_elem = _meshio_to_mdpa_type[c.type]
@@ -547,18 +541,14 @@ def write(filename, mesh, float_fmt=".16e", binary=False):
                 dimension = 3
                 break
 
-        # We identify the entities
+        # identify entities
         _write_nodes(fh, mesh.points, float_fmt, binary)
         _write_elements_and_conditions(fh, cells, tag_data, binary, dimension)
         for name, dat in mesh.point_data.items():
             _write_data(fh, "NodalData", name, dat, binary)
         cell_data_raw = raw_from_cell_data(other_data)
-        for (
-            name,
-            dat,
-        ) in (
-            cell_data_raw.items()
-        ):  # NOTE: We will assume always when writing that the components are elements (for now)
+        for name, dat in cell_data_raw.items():
+            # assume always that the components are elements (for now)
             _write_data(fh, "ElementalData", name, dat, binary)
 
 
