@@ -3,8 +3,9 @@ I/O for the Wavefront .obj file format, cf.
 <https://en.wikipedia.org/wiki/Wavefront_.obj_file>.
 """
 import datetime
+import logging
 
-import numpy
+import numpy as np
 
 from ..__about__ import __version__
 from .._exceptions import WriteError
@@ -40,11 +41,11 @@ def read_buffer(f):
 
         if split[0] == "v":
             # vertex
-            points.append([numpy.float(item) for item in split[1:]])
+            points.append([float(item) for item in split[1:]])
         elif split[0] == "vn":
-            vertex_normals.append([numpy.float(item) for item in split[1:]])
+            vertex_normals.append([float(item) for item in split[1:]])
         elif split[0] == "vt":
-            texture_coords.append([numpy.float(item) for item in split[1:]])
+            texture_coords.append([float(item) for item in split[1:]])
         elif split[0] == "s":
             # "s 1" or "s off" controls smooth shading
             pass
@@ -62,9 +63,13 @@ def read_buffer(f):
             # who knows
             pass
 
-    points = numpy.array(points)
-    texture_coords = numpy.array(texture_coords)
-    vertex_normals = numpy.array(vertex_normals)
+    # There may be empty groups, too. <https://github.com/nschloe/meshio/issues/770>
+    # Remove them.
+    face_groups = [f for f in face_groups if len(f) > 0]
+
+    points = np.array(points)
+    texture_coords = np.array(texture_coords)
+    vertex_normals = np.array(vertex_normals)
     point_data = {}
     if len(texture_coords) > 0:
         point_data["obj:vt"] = texture_coords
@@ -72,10 +77,19 @@ def read_buffer(f):
         point_data["obj:vn"] = vertex_normals
 
     # convert to numpy arrays
-    face_groups = [numpy.array(f) for f in face_groups]
-    cells = [
-        CellBlock("triangle" if f.shape[1] == 3 else "quad", f - 1) for f in face_groups
-    ]
+    face_groups = [np.array(f) for f in face_groups]
+    cells = []
+    for f in face_groups:
+        if f.shape[1] == 3:
+            cells.append(CellBlock("triangle", f - 1))
+        elif f.shape[1] == 4:
+            cells.append(CellBlock("quad", f - 1))
+        else:
+            # Anything else but triangles or quads not supported yet
+            logging.warning(
+                "meshio::obj only supports triangles and quads. "
+                "Skipping {} polygons with {} nodes".format(f.shape[0], f.shape[1])
+            )
 
     return Mesh(points, cells, point_data=point_data)
 
@@ -108,7 +122,7 @@ def write(filename, mesh):
             for vt in dat:
                 f.write(fmt.format(*vt))
 
-        for cell_type, cell_array in mesh.cells:
+        for _, cell_array in mesh.cells:
             fmt = "f " + " ".join(["{}"] * cell_array.shape[1]) + "\n"
             for c in cell_array:
                 f.write(fmt.format(*(c + 1)))
