@@ -8,7 +8,7 @@ import os
 import numpy as np
 
 from ..__about__ import __version__
-from .._exceptions import ReadError, WriteError
+from .._exceptions import ReadError
 from .._files import open_file
 from .._helpers import register
 from .._mesh import CellBlock, Mesh
@@ -159,12 +159,6 @@ def _read_binary(f, num_triangles):
 
 
 def write(filename, mesh, binary=False):
-    if not any(c.type == "triangle" for c in mesh.cells):
-        raise WriteError(
-            "STL can only write triangle cells (not {}).".format(
-                ", ".join(c.type for c in mesh.cells)
-            )
-        )
     if len(mesh.cells) > 1:
         invalid = {block.type for block in mesh.cells if block.type != "triangle"}
         logging.warning(
@@ -182,59 +176,62 @@ def write(filename, mesh, binary=False):
             [mesh.points[:, 0], mesh.points[:, 1], np.zeros(mesh.points.shape[0])]
         )
 
-    if binary:
-        _binary(filename, mesh.points, mesh.cells)
+    pts = mesh.points[mesh.get_cells_type("triangle")]
+    if "facet_normals" in mesh.cell_data:
+        normals = mesh.get_cell_data("facet_normals", "triangle")
     else:
-        _write_ascii(filename, mesh)
+        normals = np.cross(pts[:, 1] - pts[:, 0], pts[:, 2] - pts[:, 0])
+        nrm = np.sqrt(np.einsum("ij,ij->i", normals, normals))
+        normals = (normals.T / nrm).T
+
+    fun = _write_binary if binary else _write_ascii
+    fun(filename, pts, normals)
 
 
-def _compute_normals(pts):
-    normals = np.cross(pts[:, 1] - pts[:, 0], pts[:, 2] - pts[:, 0])
-    nrm = np.sqrt(np.einsum("ij,ij->i", normals, normals))
-    normals = (normals.T / nrm).T
-    return normals
-
-
-def _write_ascii(filename, mesh):
-    with open_file(filename, "wb") as fh:
-        fh.write(b"solid\n")
-        pts = mesh.points[mesh.get_cells_type("triangle")]
-        if "facet_normals" in mesh.cell_data:
-            normals = mesh.get_cell_data("facet_normals", "triangle")
-        else:
-            normals = _compute_normals(pts)
-
+def _write_ascii(filename, pts, normals):
+    with open_file(filename, "w") as fh:
+        fh.write("solid\n")
         for local_pts, normal in zip(pts, normals):
-            # facet normal 0.455194 -0.187301 -0.870469
-            #  outer loop
-            #   vertex 266.36 234.594 14.6145
-            #   vertex 268.582 234.968 15.6956
-            #   vertex 267.689 232.646 15.7283
-            #  endloop
-            # endfacet
-            out = ["facet normal {} {} {}".format(*normal), " outer loop"]
-            for pt in local_pts:
-                out += ["  vertex {} {} {}".format(*pt)]
-            out += [" endloop", "endfacet"]
-            fh.write(("\n".join(out) + "\n").encode("utf-8"))
-        fh.write(b"endsolid\n")
+            out = (
+                "\n".join(
+                    [
+                        "facet normal {} {} {}".format(*normal),
+                        " outer loop",
+                        "  vertex {} {} {}".format(*local_pts[0]),
+                        "  vertex {} {} {}".format(*local_pts[1]),
+                        "  vertex {} {} {}".format(*local_pts[2]),
+                        " endloop",
+                        "endfacet",
+                    ]
+                )
+                + "\n"
+            )
+            fh.write(out)
+        fh.write("endsolid\n")
 
 
-def _binary(filename, points, cells):
+def _write_binary(filename, pts, normals):
     with open_file(filename, "wb") as fh:
         # 80 character header data
         msg = f"This file was generated by meshio v{__version__}."
         msg += (79 - len(msg)) * "X"
         msg += "\n"
         fh.write(msg.encode("utf-8"))
-        for c in filter(lambda c: c.type == "triangle", cells):
-            pts = points[c.data]
-            normals = _compute_normals(pts)
-            fh.write(np.uint32(len(c.data)))
-            for pt, normal in zip(pts, normals):
-                fh.write(normal.astype(np.float32))
-                fh.write(pt.astype(np.float32))
-                fh.write(np.uint16(0))
+
+        fh.write(np.array(len(pts)).astype("<u4"))
+
+        dtype = np.dtype(
+            [
+                ("normal", ("<f4", 3)),
+                ("points", ("<f4", (3, 3))),
+                ("attr", "<u2"),
+            ]
+        )
+        a = np.empty(len(pts), dtype=dtype)
+        a["normal"] = normals
+        a["points"] = pts
+        a["attr"] = 0
+        a.tofile(fh)
 
 
 register("stl", [".stl"], read, {"stl": write})
