@@ -1,3 +1,4 @@
+from typing import Optional, Union
 from xml.etree import ElementTree as ET
 
 import numpy as np
@@ -9,11 +10,11 @@ from .._helpers import register
 def write(
     filename,
     mesh,
-    float_fmt=".3f",
-    stroke_width=None,
-    force_width=None,
-    fill="none",
-    stroke="black",
+    float_fmt: str = ".3f",
+    stroke_width: Optional[str] = None,
+    force_width: Optional[Union[int, float]] = None,
+    fill: str = "none",
+    stroke: str = "black",
 ):
     if mesh.points.shape[1] == 3 and not np.allclose(
         mesh.points[:, 2], 0.0, rtol=0.0, atol=1.0e-14
@@ -23,12 +24,15 @@ def write(
         )
 
     pts = mesh.points[:, :2].copy()
-    pts[:, 1] = np.max(pts[:, 1]) - pts[:, 1]
+    min_x = np.min(pts[:, 0]) if len(pts) > 0 else 0.0
+    max_x = np.max(pts[:, 0]) if len(pts) > 0 else 0.0
+    min_y = np.min(pts[:, 1]) if len(pts) > 0 else 0.0
+    max_y = np.max(pts[:, 1]) if len(pts) > 0 else 0.0
 
-    min_x = np.min(pts[:, 0])
-    min_y = np.min(pts[:, 1])
-    width = np.max(pts[:, 0]) - min_x
-    height = np.max(pts[:, 1]) - min_y
+    pts[:, 1] = max_y + min_y - pts[:, 1]
+
+    width = max_x - min_x
+    height = max_y - min_y
 
     if force_width is not None:
         scaling_factor = force_width / width
@@ -63,6 +67,7 @@ def write(
     for cell_block in mesh.cells:
         if cell_block.type not in ["line", "triangle", "quad"]:
             continue
+
         if cell_block.type == "line":
             fmt = (
                 f"M {{:{float_fmt}}} {{:{float_fmt}}}"
