@@ -1,10 +1,11 @@
 """
 I/O for Tecplot ASCII data format, cf.
+<https://download.tecplot.com/360/current/360_data_format_guide.pdf>,
 <http://paulbourke.net/dataformats/tp/>.
 """
 import logging
 
-import numpy
+import numpy as np
 
 from ..__about__ import __version__ as version
 from .._exceptions import ReadError, WriteError
@@ -30,7 +31,17 @@ zone_key_to_type = {
 }
 
 
+# 0=ORDERED
+# 1=FELINESEG
+# 2=FETRIANGLE
+# 3=FEQUADRILATERAL
+# 4=FETETRAHEDRON
+# 5=FEBRICK
+# 6=FEPOLYGON
+# 7=FEPOLYHEDRON
 tecplot_to_meshio_type = {
+    "LINESEG": "line",
+    "FELINESEG": "line",
     "TRIANGLE": "triangle",
     "FETRIANGLE": "triangle",
     "QUADRILATERAL": "quad",
@@ -43,6 +54,7 @@ tecplot_to_meshio_type = {
 
 
 meshio_to_tecplot_type = {
+    "line": "FELINESEG",
     "triangle": "FETRIANGLE",
     "quad": "FEQUADRILATERAL",
     "tetra": "FETETRAHEDRON",
@@ -56,6 +68,7 @@ meshio_only = set(meshio_to_tecplot_type.keys())
 
 
 meshio_to_tecplot_order = {
+    "line": [0, 1],
     "triangle": [0, 1, 2],
     "quad": [0, 1, 2, 3],
     "tetra": [0, 1, 2, 3],
@@ -76,6 +89,7 @@ meshio_to_tecplot_order_2 = {
 
 
 meshio_type_to_ndim = {
+    "line": 1,
     "triangle": 2,
     "quad": 2,
     "tetra": 3,
@@ -91,11 +105,34 @@ def read(filename):
     return out
 
 
-def read_buffer(f):
-    while True:
+def readline(f):
+    line = f.readline().strip()
+    while line.startswith("#"):
         line = f.readline().strip()
 
+    return line
+
+
+def read_buffer(f):
+    while True:
+        line = readline(f)
+
         if line.upper().startswith("VARIABLES"):
+            # Multilines for VARIABLES appears to work only if
+            # variable name is double quoted
+            lines = [line]
+            i = f.tell()
+            line = readline(f).upper()
+            while True:
+                if line.startswith('"'):
+                    lines += [line]
+                    i = f.tell()
+                    line = readline(f).upper()
+                else:
+                    f.seek(i)
+                    break
+            line = " ".join(lines)
+
             variables = _read_variables(line)
 
         elif line.upper().startswith("ZONE"):
@@ -108,12 +145,12 @@ def read_buffer(f):
             # is valid (and understood by ParaView and VisIt).
             lines = [line]
             i = f.tell()
-            line = f.readline().strip().upper()
+            line = readline(f).upper()
             while True:
                 if line and not line[0].isdigit():
                     lines += [line]
                     i = f.tell()
-                    line = f.readline().strip().upper()
+                    line = readline(f).upper()
                 else:
                     f.seek(i)
                     break
@@ -142,9 +179,9 @@ def read_buffer(f):
             break
 
     data = (
-        numpy.split(numpy.concatenate(data), numpy.cumsum(num_data[:-1]))
+        np.split(np.concatenate(data), np.cumsum(num_data[:-1]))
         if zone_format == "FEBLOCK"
-        else numpy.transpose(data)
+        else np.transpose(data)
     )
     data = {k: v for k, v in zip(variables, data)}
 
@@ -158,9 +195,9 @@ def read_buffer(f):
     x = "X" if "X" in point_data.keys() else "x"
     y = "Y" if "Y" in point_data.keys() else "y"
     z = "Z" if "Z" in point_data.keys() else "z" if "z" in point_data.keys() else ""
-    points = numpy.column_stack((point_data.pop(x), point_data.pop(y)))
+    points = np.column_stack((point_data.pop(x), point_data.pop(y)))
     if z:
-        points = numpy.column_stack((points, point_data.pop(z)))
+        points = np.column_stack((points, point_data.pop(z)))
     cells = [(tecplot_to_meshio_type[zone_type], cells - 1)]
 
     return Mesh(points, cells, point_data, cell_data)
@@ -220,7 +257,7 @@ def _read_zone(line):
     # Split remaining key/value pairs separated by '='
     line = [x for x in line.replace(",", " ").split() if x != "="]
     i = 0
-    while i < len(line) - 1:
+    while i < len(line):
         if "=" in line[i]:
             if not (line[i].startswith("=") or line[i].endswith("=")):
                 key, value = line[i].split("=")
@@ -277,7 +314,7 @@ def _parse_fezone(zone, variables):
         raise ReadError("Number of elements not found")
 
     # Variable locations
-    is_cell_centered = numpy.zeros(len(variables), dtype=int)
+    is_cell_centered = np.zeros(len(variables), dtype=int)
     if zone_format == "FEBLOCK":
         if "NV" in zone.keys():
             node_value = zone.pop("NV")
@@ -304,19 +341,19 @@ def _parse_fezone(zone, variables):
 def _read_zone_data(f, num_data, num_cells, zone_format):
     data, count = [], 0
     while count < num_data:
-        line = f.readline().strip().split()
+        line = readline(f).split()
         if line:
             data += [[float(x) for x in line]]
             count += len(line) if zone_format == "FEBLOCK" else 1
 
     cells, count = [], 0
     while count < num_cells:
-        line = f.readline().strip().split()
+        line = readline(f).split()
         if line:
             cells += [[[int(x) for x in line]]]
             count += 1
 
-    return data, numpy.concatenate(cells)
+    return data, np.concatenate(cells)
 
 
 def write(filename, mesh):
@@ -336,13 +373,13 @@ def write(filename, mesh):
             )
 
     # Define cells and zone type
-    cell_types = numpy.unique(cell_types)
+    cell_types = np.unique(cell_types)
     if len(cell_types) == 0:
         raise WriteError("No cell type supported by Tecplot in mesh")
     elif len(cell_types) == 1:
         # Nothing much to do except converting pyramids and wedges to hexahedra
         zone_type = meshio_to_tecplot_type[cell_types[0]]
-        cells = numpy.concatenate(
+        cells = np.concatenate(
             [
                 mesh.cells[ic].data[:, meshio_to_tecplot_order[mesh.cells[ic].type]]
                 for ic in cell_blocks
@@ -353,13 +390,13 @@ def write(filename, mesh):
         num_dims = [meshio_type_to_ndim[mesh.cells[ic].type] for ic in cell_blocks]
 
         # Skip 2D cells if it does
-        if len(numpy.unique(num_dims)) == 2:
+        if len(np.unique(num_dims)) == 2:
             logging.warning("Mesh contains 2D and 3D cells. Skipping 2D cells.")
             cell_blocks = [ic for ic, ndim in zip(cell_blocks, num_dims) if ndim == 3]
 
         # Convert 2D cells to quads / 3D cells to hexahedra
         zone_type = "FEQUADRILATERAL" if num_dims[0] == 2 else "FEBRICK"
-        cells = numpy.concatenate(
+        cells = np.concatenate(
             [
                 mesh.cells[ic].data[:, meshio_to_tecplot_order_2[mesh.cells[ic].type]]
                 for ic in cell_blocks
@@ -384,42 +421,42 @@ def write(filename, mesh):
                 varrange[0] += 1
             elif v.ndim == 2:
                 for i, vv in enumerate(v.T):
-                    variables += ["{}_{}".format(k, i)]
+                    variables += [f"{k}_{i}"]
                     data += [vv]
                     varrange[0] += 1
         else:
-            logging.warning("Skipping point data '{}'.".format(k))
+            logging.warning(f"Skipping point data '{k}'.")
 
     if mesh.cell_data:
         varrange[1] = varrange[0] - 1
         for k, v in mesh.cell_data.items():
             if k not in {"X", "Y", "Z", "x", "y", "z"}:
-                v = numpy.concatenate([v[ic] for ic in cell_blocks])
+                v = np.concatenate([v[ic] for ic in cell_blocks])
                 if v.ndim == 1:
                     variables += [k]
                     data += [v]
                     varrange[1] += 1
                 elif v.ndim == 2:
                     for i, vv in enumerate(v.T):
-                        variables += ["{}_{}".format(k, i)]
+                        variables += [f"{k}_{i}"]
                         data += [vv]
                         varrange[1] += 1
             else:
-                logging.warning("Skipping cell data '{}'.".format(k))
+                logging.warning(f"Skipping cell data '{k}'.")
 
     with open_file(filename, "w") as f:
         # Title
-        f.write('TITLE = "Written by meshio v{}"\n'.format(version))
+        f.write(f'TITLE = "Written by meshio v{version}"\n')
 
         # Variables
-        variables_str = ", ".join('"{}"'.format(var) for var in variables)
-        f.write("VARIABLES = {}\n".format(variables_str))
+        variables_str = ", ".join(f'"{var}"' for var in variables)
+        f.write(f"VARIABLES = {variables_str}\n")
 
         # Zone record
         num_nodes = len(mesh.points)
         num_cells = sum(len(mesh.cells[ic].data) for ic in cell_blocks)
-        f.write("ZONE NODES = {}, ELEMENTS = {},\n".format(num_nodes, num_cells))
-        f.write("DATAPACKING = BLOCK, ZONETYPE = {}".format(zone_type))
+        f.write(f"ZONE NODES = {num_nodes}, ELEMENTS = {num_cells},\n")
+        f.write(f"DATAPACKING = BLOCK, ZONETYPE = {zone_type}")
         if varrange[0] <= varrange[1]:
             f.write(",\n")
             varlocation_str = (
@@ -427,7 +464,7 @@ def write(filename, mesh):
                 if varrange[0] == varrange[1]
                 else "{}-{}".format(varrange[0], varrange[1])
             )
-            f.write("VARLOCATION = ([{}] = CELLCENTERED)\n".format(varlocation_str))
+            f.write(f"VARLOCATION = ([{varlocation_str}] = CELLCENTERED)\n")
         else:
             f.write("\n")
 
@@ -436,14 +473,13 @@ def write(filename, mesh):
             _write_table(f, arr)
 
         # CellBlock
-        cells = numpy.array(cells) + 1
         for cell in cells:
-            f.write("{}\n".format(" ".join(str(c) for c in cell)))
+            f.write("{}\n".format(" ".join(str(c + 1) for c in cell)))
 
 
 def _write_table(f, data, ncol=20):
     nrow = len(data) // ncol
-    lines = numpy.split(data, numpy.full(nrow, ncol).cumsum())
+    lines = np.split(data, np.full(nrow, ncol).cumsum())
     for line in lines:
         if len(line):
             f.write("{}\n".format(" ".join(str(l) for l in line)))
