@@ -4,7 +4,7 @@ I/O for VTK <https://www.vtk.org/wp-content/uploads/2015/04/file-formats.pdf>.
 import logging
 from functools import reduce
 
-import numpy
+import numpy as np
 
 from ..__about__ import __version__
 from .._common import (
@@ -18,7 +18,7 @@ from .._files import open_file
 from .._helpers import register
 from .._mesh import CellBlock, Mesh
 
-vtk_type_to_numnodes = numpy.array(
+vtk_type_to_numnodes = np.array(
     [
         0,  # empty
         1,  # vertex
@@ -61,7 +61,6 @@ vtk_type_to_numnodes = numpy.array(
 
 
 # These are all VTK data types.
-# One sometimes finds 'vtktypeint64', but this is ill-formed.
 vtk_to_numpy_dtype_name = {
     "bit": "bool",
     "unsigned_char": "uint8",
@@ -74,9 +73,14 @@ vtk_to_numpy_dtype_name = {
     "long": "int64",
     "float": "float32",
     "double": "float64",
+    "vtktypeint32": "int32",  # vtk DataFile Version 5.1
+    "vtktypeint64": "int64",  # vtk DataFile Version 5.1
+    "vtkidtype": "int32",  # may be either 32-bit or 64-bit (VTK_USE_64BIT_IDS)
 }
 
-numpy_to_vtk_dtype = {v: k for k, v in vtk_to_numpy_dtype_name.items()}
+numpy_to_vtk_dtype = {
+    v: k for k, v in vtk_to_numpy_dtype_name.items() if "vtk" not in k
+}
 
 # supported vtk dataset types
 vtk_dataset_types = [
@@ -113,6 +117,7 @@ vtk_sections = [
     "POINT_DATA",
     "CELL_DATA",
     "LOOKUP_TABLE",
+    "COLOR_SCALARS",
 ]
 
 
@@ -140,8 +145,7 @@ class Info:
 
 
 def read(filename):
-    """Reads a VTK vtk file.
-    """
+    """Reads a VTK vtk file."""
     with open_file(filename, "rb") as f:
         out = read_buffer(f)
     return out
@@ -157,7 +161,7 @@ def read_buffer(f):
 
     data_type = f.readline().decode("utf-8").strip().upper()
     if data_type not in ["ASCII", "BINARY"]:
-        raise ReadError("Unknown VTK data type '{}'.".format(data_type))
+        raise ReadError(f"Unknown VTK data type '{data_type}'.")
     info.is_ascii = data_type == "ASCII"
 
     while True:
@@ -212,8 +216,29 @@ def _read_section(f, info):
 
     elif info.section == "CELLS":
         info.active = "CELLS"
-        info.num_items = int(info.split[2])
-        info.c = _read_cells(f, info.is_ascii, info.num_items)
+        last_pos = f.tell()
+        try:
+            line = f.readline().decode("utf-8")
+        except UnicodeDecodeError:
+            line = ""
+        if "OFFSETS" in line:
+            # vtk DataFile Version 5.1 - appearing in Paraview 5.8.1 outputs
+            # No specification found for this file format.
+            # See the question on ParaView Discourse Forum:
+            # <https://discourse.paraview.org/t/specification-of-vtk-datafile-version-5-1/5127>.
+            info.num_offsets = int(info.split[1])
+            info.num_items = int(info.split[2])
+            dtype = np.dtype(vtk_to_numpy_dtype_name[line.split()[1]])
+            offsets = _read_cells(f, info.is_ascii, info.num_offsets, dtype)
+            line = f.readline().decode("utf-8")
+            assert "CONNECTIVITY" in line
+            dtype = np.dtype(vtk_to_numpy_dtype_name[line.split()[1]])
+            connectivity = _read_cells(f, info.is_ascii, info.num_items, dtype)
+            info.c = (offsets, connectivity)
+        else:
+            f.seek(last_pos)
+            info.num_items = int(info.split[2])
+            info.c = _read_cells(f, info.is_ascii, info.num_items)
 
     elif info.section == "CELL_TYPES":
         info.active = "CELL_TYPES"
@@ -230,8 +255,17 @@ def _read_section(f, info):
 
     elif info.section == "LOOKUP_TABLE":
         info.num_items = int(info.split[2])
-        data = numpy.fromfile(f, count=info.num_items * 4, sep=" ", dtype=float)
-        rgba = data.reshape((info.num_items, 4))  # noqa F841
+        np.fromfile(f, count=info.num_items * 4, sep=" ", dtype=float)
+        # rgba = data.reshape((info.num_items, 4))
+
+    elif info.section == "COLOR_SCALARS":
+        nValues = int(info.split[2])
+        # re-use num_items from active POINT/CELL_DATA
+        num_items = info.num_items
+        dtype = np.ubyte
+        if info.is_ascii:
+            dtype = float
+        np.fromfile(f, count=num_items * nValues, dtype=dtype)
 
 
 def _read_subsection(f, info):
@@ -269,7 +303,7 @@ def _read_subsection(f, info):
     elif info.section == "FIELD":
         d.update(_read_fields(f, int(info.split[2]), info.is_ascii))
     else:
-        raise ReadError("Unknown section '{}'.".format(info.section))
+        raise ReadError(f"Unknown section '{info.section}'.")
 
 
 def _check_mesh(info):
@@ -287,7 +321,7 @@ def _check_mesh(info):
             else info.dataset["ASPECT_RATIO"]
         )
         axis = [
-            numpy.linspace(ori[i], ori[i] + (dim[i] - 1.0) * spa[i], dim[i])
+            np.linspace(ori[i], ori[i] + (dim[i] - 1.0) * spa[i], dim[i])
             for i in range(3)
         ]
         info.points = _generate_points(axis)
@@ -306,35 +340,37 @@ def _check_mesh(info):
 
 def _generate_cells(dim):
     ele_dim = [d - 1 for d in dim if d > 1]
-    ele_no = numpy.prod(ele_dim, dtype=int)
+    # TODO use math.prod when requiring Python 3.8+? this would save the int conversion
+    # <https://github.com/microsoft/pyright/issues/1226>
+    ele_no = int(np.prod(ele_dim))
     spatial_dim = len(ele_dim)
 
     if spatial_dim == 1:
         # cells are lines in 1D
-        cells = numpy.empty((ele_no, 3), dtype=int)
+        cells = np.empty((ele_no, 3), dtype=int)
         cells[:, 0] = 2
-        cells[:, 1] = numpy.arange(ele_no, dtype=int)
+        cells[:, 1] = np.arange(ele_no, dtype=int)
         cells[:, 2] = cells[:, 1] + 1
-        cell_types = numpy.full(ele_no, 3, dtype=int)
+        cell_types = np.full(ele_no, 3, dtype=int)
     elif spatial_dim == 2:
         # cells are quad in 2D
-        cells = numpy.empty((ele_no, 5), dtype=int)
+        cells = np.empty((ele_no, 5), dtype=int)
         cells[:, 0] = 4
-        cells[:, 1] = numpy.arange(0, ele_no, dtype=int)
-        cells[:, 1] += numpy.arange(0, ele_no, dtype=int) // ele_dim[0]
+        cells[:, 1] = np.arange(0, ele_no, dtype=int)
+        cells[:, 1] += np.arange(0, ele_no, dtype=int) // ele_dim[0]
         cells[:, 2] = cells[:, 1] + 1
         cells[:, 3] = cells[:, 1] + 2 + ele_dim[0]
         cells[:, 4] = cells[:, 3] - 1
-        cell_types = numpy.full(ele_no, 9, dtype=int)
+        cell_types = np.full(ele_no, 9, dtype=int)
     else:
         # cells are hex in 3D
-        cells = numpy.empty((ele_no, 9), dtype=int)
+        cells = np.empty((ele_no, 9), dtype=int)
         cells[:, 0] = 8
-        cells[:, 1] = numpy.arange(ele_no)
+        cells[:, 1] = np.arange(ele_no)
         cells[:, 1] += (ele_dim[0] + ele_dim[1] + 1) * (
-            numpy.arange(ele_no) // (ele_dim[0] * ele_dim[1])
+            np.arange(ele_no) // (ele_dim[0] * ele_dim[1])
         )
-        cells[:, 1] += (numpy.arange(ele_no) % (ele_dim[0] * ele_dim[1])) // ele_dim[0]
+        cells[:, 1] += (np.arange(ele_no) % (ele_dim[0] * ele_dim[1])) // ele_dim[0]
         cells[:, 2] = cells[:, 1] + 1
         cells[:, 3] = cells[:, 1] + 2 + ele_dim[0]
         cells[:, 4] = cells[:, 3] - 1
@@ -342,7 +378,7 @@ def _generate_cells(dim):
         cells[:, 6] = cells[:, 5] + 1
         cells[:, 7] = cells[:, 5] + 2 + ele_dim[0]
         cells[:, 8] = cells[:, 7] - 1
-        cell_types = numpy.full(ele_no, 12, dtype=int)
+        cell_types = np.full(ele_no, 12, dtype=int)
 
     return cells.reshape(-1), cell_types
 
@@ -352,8 +388,8 @@ def _generate_points(axis):
     y_dim = len(axis[1])
     z_dim = len(axis[2])
     pnt_no = x_dim * y_dim * z_dim
-    x_id, y_id, z_id = numpy.mgrid[0:x_dim, 0:y_dim, 0:z_dim]
-    points = numpy.empty((pnt_no, 3), dtype=axis[0].dtype)
+    x_id, y_id, z_id = np.mgrid[0:x_dim, 0:y_dim, 0:z_dim]
+    points = np.empty((pnt_no, 3), dtype=axis[0].dtype)
     # VTK sorts points and cells in Fortran order
     points[:, 0] = axis[0][x_id.reshape(-1, order="F")]
     points[:, 1] = axis[1][y_id.reshape(-1, order="F")]
@@ -362,14 +398,14 @@ def _generate_points(axis):
 
 
 def _read_coords(f, data_type, is_ascii, num_points):
-    dtype = numpy.dtype(vtk_to_numpy_dtype_name[data_type])
+    dtype = np.dtype(vtk_to_numpy_dtype_name[data_type])
     if is_ascii:
-        coords = numpy.fromfile(f, count=num_points, sep=" ", dtype=dtype)
+        coords = np.fromfile(f, count=num_points, sep=" ", dtype=dtype)
     else:
         # Binary data is big endian, see
         # <https://www.vtk.org/Wiki/VTK/Writing_VTK_files_using_python#.22legacy.22>.
         dtype = dtype.newbyteorder(">")
-        coords = numpy.fromfile(f, count=num_points, dtype=dtype)
+        coords = np.fromfile(f, count=num_points, dtype=dtype)
         line = f.readline().decode("utf-8")
         if line != "\n":
             raise ReadError()
@@ -377,25 +413,26 @@ def _read_coords(f, data_type, is_ascii, num_points):
 
 
 def _read_points(f, data_type, is_ascii, num_points):
-    dtype = numpy.dtype(vtk_to_numpy_dtype_name[data_type])
+    dtype = np.dtype(vtk_to_numpy_dtype_name[data_type])
     if is_ascii:
-        points = numpy.fromfile(f, count=num_points * 3, sep=" ", dtype=dtype)
+        points = np.fromfile(f, count=num_points * 3, sep=" ", dtype=dtype)
     else:
         # Binary data is big endian, see
         # <https://www.vtk.org/Wiki/VTK/Writing_VTK_files_using_python#.22legacy.22>.
         dtype = dtype.newbyteorder(">")
-        points = numpy.fromfile(f, count=num_points * 3, dtype=dtype)
+        points = np.fromfile(f, count=num_points * 3, dtype=dtype)
         line = f.readline().decode("utf-8")
         if line != "\n":
             raise ReadError()
     return points.reshape((num_points, 3))
 
 
-def _read_cells(f, is_ascii, num_items):
+def _read_cells(f, is_ascii, num_items, dtype=np.dtype("int32")):
     if is_ascii:
-        c = numpy.fromfile(f, count=num_items, sep=" ", dtype=int)
+        c = np.fromfile(f, count=num_items, sep=" ", dtype=dtype)
     else:
-        c = numpy.fromfile(f, count=num_items, dtype=">i4")
+        dtype = dtype.newbyteorder(">")
+        c = np.fromfile(f, count=num_items, dtype=dtype)
         line = f.readline().decode("utf-8")
         if line != "\n":
             raise ReadError()
@@ -404,10 +441,10 @@ def _read_cells(f, is_ascii, num_items):
 
 def _read_cell_types(f, is_ascii, num_items):
     if is_ascii:
-        ct = numpy.fromfile(f, count=int(num_items), sep=" ", dtype=int)
+        ct = np.fromfile(f, count=int(num_items), sep=" ", dtype=int)
     else:
         # binary
-        ct = numpy.fromfile(f, count=int(num_items), dtype=">i4")
+        ct = np.fromfile(f, count=int(num_items), dtype=">i4")
         line = f.readline().decode("utf-8")
         # Sometimes, there's no newline at the end
         if line.strip() != "":
@@ -428,22 +465,23 @@ def _read_scalar_field(f, num_data, split, is_ascii):
     if not (0 < num_comp < 5):
         raise ReadError("The parameter numComp must range between (1,4) inclusive")
 
-    dtype = numpy.dtype(vtk_to_numpy_dtype_name[data_type])
+    dtype = np.dtype(vtk_to_numpy_dtype_name[data_type])
     lt, _ = f.readline().decode("utf-8").split()
     if lt.upper() != "LOOKUP_TABLE":
         raise ReadError()
 
     if is_ascii:
-        data = numpy.fromfile(f, count=num_data, sep=" ", dtype=dtype)
+        data = np.fromfile(f, count=num_data * num_comp, sep=" ", dtype=dtype)
     else:
         # Binary data is big endian, see
         # <https://www.vtk.org/Wiki/VTK/Writing_VTK_files_using_python#.22legacy.22>.
         dtype = dtype.newbyteorder(">")
-        data = numpy.fromfile(f, count=num_data, dtype=dtype)
+        data = np.fromfile(f, count=num_data * num_comp, dtype=dtype)
         line = f.readline().decode("utf-8")
         if line != "\n":
             raise ReadError()
 
+    data = data.reshape(-1, num_comp)
     return {data_name: data}
 
 
@@ -451,17 +489,18 @@ def _read_field(f, num_data, split, shape, is_ascii):
     data_name = split[1]
     data_type = split[2].lower()
 
-    dtype = numpy.dtype(vtk_to_numpy_dtype_name[data_type])
+    dtype = np.dtype(vtk_to_numpy_dtype_name[data_type])
+    # prod()
     # <https://stackoverflow.com/q/2104782/353337>
     k = reduce((lambda x, y: x * y), shape)
 
     if is_ascii:
-        data = numpy.fromfile(f, count=k * num_data, sep=" ", dtype=dtype)
+        data = np.fromfile(f, count=k * num_data, sep=" ", dtype=dtype)
     else:
         # Binary data is big endian, see
         # <https://www.vtk.org/Wiki/VTK/Writing_VTK_files_using_python#.22legacy.22>.
         dtype = dtype.newbyteorder(">")
-        data = numpy.fromfile(f, count=k * num_data, dtype=dtype)
+        data = np.fromfile(f, count=k * num_data, dtype=dtype)
         line = f.readline().decode("utf-8")
         if line != "\n":
             raise ReadError()
@@ -482,15 +521,15 @@ def _read_fields(f, num_fields, is_ascii):
 
         shape0 = int(shape0)
         shape1 = int(shape1)
-        dtype = numpy.dtype(vtk_to_numpy_dtype_name[data_type.lower()])
+        dtype = np.dtype(vtk_to_numpy_dtype_name[data_type.lower()])
 
         if is_ascii:
-            dat = numpy.fromfile(f, count=shape0 * shape1, sep=" ", dtype=dtype)
+            dat = np.fromfile(f, count=shape0 * shape1, sep=" ", dtype=dtype)
         else:
             # Binary data is big endian, see
             # <https://www.vtk.org/Wiki/VTK/Writing_VTK_files_using_python#.22legacy.22>.
             dtype = dtype.newbyteorder(">")
-            dat = numpy.fromfile(f, count=shape0 * shape1, dtype=dtype)
+            dat = np.fromfile(f, count=shape0 * shape1, dtype=dtype)
             line = f.readline().decode("utf-8")
             if line != "\n":
                 raise ReadError()
@@ -518,15 +557,16 @@ def translate_cells(data, types, cell_data_raw):
     # Translate it into the cells array.
     # `data` is a one-dimensional vector with
     # (num_points0, p0, p1, ... ,pk, numpoints1, p10, p11, ..., p1k, ...
-    has_polygon = numpy.any(types == meshio_to_vtk_type["polygon"])
+    # or a tuple with (offsets, connectivity)
+    has_polygon = np.any(types == meshio_to_vtk_type["polygon"])
 
     cells = []
     cell_data = {}
     if has_polygon:
-        numnodes = numpy.empty(len(types), dtype=int)
+        numnodes = np.empty(len(types), dtype=int)
         # If some polygons are in the VTK file, loop over the cells
         numcells = len(types)
-        offsets = numpy.empty(len(types), dtype=int)
+        offsets = np.empty(len(types), dtype=int)
         offsets[0] = 0
         for idx in range(numcells - 1):
             numnodes[idx] = data[offsets[idx]]
@@ -534,7 +574,7 @@ def translate_cells(data, types, cell_data_raw):
 
         idx = numcells - 1
         numnodes[idx] = data[offsets[idx]]
-        if not numpy.all(numnodes == data[offsets]):
+        if not np.all(numnodes == data[offsets]):
             raise ReadError()
 
         # TODO: cell_data
@@ -556,28 +596,38 @@ def translate_cells(data, types, cell_data_raw):
 
         # convert data to numpy arrays
         for k, c in enumerate(cells):
-            cells[k] = CellBlock(c.type, numpy.array(c.data))
+            cells[k] = CellBlock(c.type, np.array(c.data))
     else:
         # Deduct offsets from the cell types. This is much faster than manually going
         # through the data array. Slight disadvantage: This doesn't work for cells with
         # a custom number of points.
         numnodes = vtk_type_to_numnodes[types]
-        if not numpy.all(numnodes > 0):
+        if not np.all(numnodes > 0):
             raise ReadError("File contains cells that meshio cannot handle.")
-        offsets = numpy.cumsum(numnodes + 1) - (numnodes + 1)
+        if isinstance(data, tuple):
+            offsets, conn = data
+            if not np.all(numnodes == np.diff(offsets)):
+                raise ReadError()
+            idx0 = 0
+        else:
+            offsets = np.cumsum(numnodes + 1) - (numnodes + 1)
 
-        if not numpy.all(numnodes == data[offsets]):
-            raise ReadError()
+            if not np.all(numnodes == data[offsets]):
+                raise ReadError()
+            idx0 = 1
+            conn = data
 
-        b = numpy.concatenate(
-            [[0], numpy.where(types[:-1] != types[1:])[0] + 1, [len(types)]]
+        b = np.concatenate(
+            [[0], np.where(types[:-1] != types[1:])[0] + 1, [len(types)]]
         )
         for start, end in zip(b[:-1], b[1:]):
+            if start == end:
+                continue
             meshio_type = vtk_to_meshio_type[types[start]]
-            n = data[offsets[start]]
-            cell_idx = 1 + _vtk_to_meshio_order(types[start], n, dtype=offsets.dtype)
-            indices = numpy.add.outer(offsets[start:end], cell_idx)
-            cells.append(CellBlock(meshio_type, data[indices]))
+            n = numnodes[start]
+            cell_idx = idx0 + _vtk_to_meshio_order(types[start], n, dtype=offsets.dtype)
+            indices = np.add.outer(offsets[start:end], cell_idx)
+            cells.append(CellBlock(meshio_type, conn[indices]))
             for name, d in cell_data_raw.items():
                 if name not in cell_data:
                     cell_data[name] = []
@@ -588,7 +638,7 @@ def translate_cells(data, types, cell_data_raw):
 
 def write(filename, mesh, binary=True):
     def pad(array):
-        return numpy.pad(array, ((0, 0), (0, 1)), "constant")
+        return np.pad(array, ((0, 0), (0, 1)), "constant")
 
     if mesh.points.shape[1] == 2:
         logging.warning(
@@ -622,7 +672,7 @@ def write(filename, mesh, binary=True):
 
     with open_file(filename, "wb") as f:
         f.write(b"# vtk DataFile Version 4.2\n")
-        f.write("written by meshio v{}\n".format(__version__).encode("utf-8"))
+        f.write(f"written by meshio v{__version__}\n".encode("utf-8"))
         f.write(("BINARY\n" if binary else "ASCII\n").encode("utf-8"))
         f.write(b"DATASET UNSTRUCTURED_GRID\n")
 
@@ -633,13 +683,13 @@ def write(filename, mesh, binary=True):
         # write point data
         if mesh.point_data:
             num_points = mesh.points.shape[0]
-            f.write("POINT_DATA {}\n".format(num_points).encode("utf-8"))
+            f.write(f"POINT_DATA {num_points}\n".encode("utf-8"))
             _write_field_data(f, mesh.point_data, binary)
 
         # write cell data
         if mesh.cell_data:
             total_num_cells = sum(len(c.data) for c in mesh.cells)
-            f.write("CELL_DATA {}\n".format(total_num_cells).encode("utf-8"))
+            f.write(f"CELL_DATA {total_num_cells}\n".encode("utf-8"))
             _write_field_data(f, mesh.cell_data, binary)
 
 
@@ -669,17 +719,17 @@ def _write_cells(f, cells, binary):
     total_num_idx = sum([c.data.size for c in cells])
     # For each cell, the number of nodes is stored
     total_num_idx += total_num_cells
-    f.write("CELLS {} {}\n".format(total_num_cells, total_num_idx).encode("utf-8"))
+    f.write(f"CELLS {total_num_cells} {total_num_idx}\n".encode("utf-8"))
     if binary:
         for c in cells:
             n = c.data.shape[1]
             cell_idx = _meshio_to_vtk_order(c.type, n)
-            dtype = numpy.dtype(">i4")
+            dtype = np.dtype(">i4")
             # One must force endianness here:
             # <https://github.com/numpy/numpy/issues/15088>
-            numpy.column_stack(
+            np.column_stack(
                 [
-                    numpy.full(c.data.shape[0], n, dtype=dtype),
+                    np.full(c.data.shape[0], n, dtype=dtype),
                     c.data[:, cell_idx].astype(dtype),
                 ],
             ).astype(dtype).tofile(f, sep="")
@@ -690,29 +740,27 @@ def _write_cells(f, cells, binary):
             n = c.data.shape[1]
             cell_idx = _meshio_to_vtk_order(c.type, n)
             # prepend a column with the value n
-            numpy.column_stack(
+            np.column_stack(
                 [
-                    numpy.full(c.data.shape[0], n, dtype=c.data.dtype),
+                    np.full(c.data.shape[0], n, dtype=c.data.dtype),
                     c.data[:, cell_idx],
                 ]
             ).tofile(f, sep="\n")
             f.write(b"\n")
 
     # write cell types
-    f.write("CELL_TYPES {}\n".format(total_num_cells).encode("utf-8"))
+    f.write(f"CELL_TYPES {total_num_cells}\n".encode("utf-8"))
     if binary:
         for c in cells:
             key_ = c.type[:7] if c.type[:7] == "polygon" else c.type
             vtk_type = meshio_to_vtk_type[key_]
-            numpy.full(len(c.data), vtk_type, dtype=numpy.dtype(">i4")).tofile(
-                f, sep=""
-            )
+            np.full(len(c.data), vtk_type, dtype=np.dtype(">i4")).tofile(f, sep="")
         f.write(b"\n")
     else:
         # ascii
         for c in cells:
             key_ = c.type[:7] if c.type[:7] == "polygon" else c.type
-            numpy.full(len(c.data), meshio_to_vtk_type[key_]).tofile(f, sep="\n")
+            np.full(len(c.data), meshio_to_vtk_type[key_]).tofile(f, sep="\n")
             f.write(b"\n")
 
 
@@ -720,7 +768,7 @@ def _write_field_data(f, data, binary):
     f.write(("FIELD FieldData {}\n".format(len(data))).encode("utf-8"))
     for name, values in data.items():
         if isinstance(values, list):
-            values = numpy.concatenate(values)
+            values = np.concatenate(values)
         if len(values.shape) == 1:
             num_tuples = values.shape[0]
             num_components = 1
@@ -729,9 +777,7 @@ def _write_field_data(f, data, binary):
             num_components = values.shape[1]
 
         if " " in name:
-            raise WriteError(
-                "VTK doesn't support spaces in field names ('{}').".format(name)
-            )
+            raise WriteError(f"VTK doesn't support spaces in field names ('{name}').")
 
         f.write(
             (
@@ -748,7 +794,7 @@ def _write_field_data(f, data, binary):
         else:
             # ascii
             values.tofile(f, sep=" ")
-            # numpy.savetxt(f, points)
+            # np.savetxt(f, points)
         f.write(b"\n")
 
 
