@@ -1,5 +1,4 @@
 import copy
-import os
 import string
 import tempfile
 from pathlib import Path
@@ -8,12 +7,11 @@ import numpy as np
 
 import meshio
 
-TEST_DIR = Path(__file__).resolve().parent
-MESHES_DIR = TEST_DIR / "meshes"
-
 # In general:
 # Use values with an infinite decimal representation to test precision.
 
+empty_mesh = meshio.Mesh(np.empty((0, 3)), [])
+
 line_mesh = meshio.Mesh(
     np.array([[0.0, 0.0, 0.0], [1.0, 0.0, 0.0], [1.0, 1.0, 0.0], [0.0, 1.0, 0.0]]) / 3,
     [("line", [[0, 1], [0, 2], [0, 3], [1, 2], [2, 3]])],
@@ -21,7 +19,7 @@ line_mesh = meshio.Mesh(
 
 tri_mesh_2d = meshio.Mesh(
     np.array([[0.0, 0.0], [1.0, 0.0], [1.0, 1.0], [0.0, 1.0]]) / 3,
-    [("triangle", np.array([[0, 1, 2], [0, 2, 3]]))],
+    [("triangle", [[0, 1, 2], [0, 2, 3]])],
 )
 
 tri_mesh = meshio.Mesh(
@@ -61,7 +59,7 @@ quad_mesh = meshio.Mesh(
         ]
     )
     / 3.0,
-    [("quad", np.array([[0, 1, 4, 5], [1, 2, 3, 4]]))],
+    [("quad", [[0, 1, 4, 5], [1, 2, 3, 4]])],
 )
 
 d = 0.1
@@ -84,7 +82,7 @@ quad8_mesh = meshio.Mesh(
         ]
     )
     / 3.0,
-    [("quad8", np.array([[0, 1, 2, 3, 4, 5, 6, 7], [1, 8, 9, 2, 10, 11, 12, 5]]))],
+    [("quad8", [[0, 1, 2, 3, 4, 5, 6, 7], [1, 8, 9, 2, 10, 11, 12, 5]])],
 )
 
 tri_quad_mesh = meshio.Mesh(
@@ -100,8 +98,8 @@ tri_quad_mesh = meshio.Mesh(
     )
     / 3.0,
     [
-        ("triangle", np.array([[0, 1, 4], [0, 4, 5]])),
-        ("quad", np.array([[1, 2, 3, 4]])),
+        ("triangle", [[0, 1, 4], [0, 4, 5]]),
+        ("quad", [[1, 2, 3, 4]]),
     ],
 )
 
@@ -119,8 +117,8 @@ quad_tri_mesh = meshio.Mesh(
     )
     / 3.0,
     [
-        ("quad", np.array([[1, 2, 3, 4]])),
-        ("triangle", np.array([[0, 1, 4], [0, 4, 5]])),
+        ("quad", [[1, 2, 3, 4]]),
+        ("triangle", [[0, 1, 4], [0, 4, 5]]),
     ],
 )
 
@@ -135,7 +133,7 @@ tet_mesh = meshio.Mesh(
         ]
     )
     / 3.0,
-    [("tetra", np.array([[0, 1, 2, 4], [0, 2, 3, 4]]))],
+    [("tetra", [[0, 1, 2, 4], [0, 2, 3, 4]])],
 )
 
 tet10_mesh = meshio.Mesh(
@@ -155,7 +153,7 @@ tet10_mesh = meshio.Mesh(
         ]
     )
     / 3.0,
-    [("tetra10", np.array([[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]]))],
+    [("tetra10", [[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]])],
 )
 
 hex_mesh = meshio.Mesh(
@@ -247,18 +245,16 @@ polygon_mesh = meshio.Mesh(
 )
 
 polyhedron_mesh = meshio.Mesh(
-    np.array(
-        [  # Two layers of a unit square
-            [0.0, 0.0, 0.0],
-            [1.0, 0.0, 0.0],
-            [1.0, 1.0, 0.0],
-            [0.0, 1.0, 0.0],
-            [0.0, 0.0, 1.0],
-            [1.0, 0.0, 1.0],
-            [1.0, 1.0, 1.0],
-            [0.0, 1.0, 1.0],
-        ]
-    ),
+    [  # Two layers of a unit square
+        [0.0, 0.0, 0.0],
+        [1.0, 0.0, 0.0],
+        [1.0, 1.0, 0.0],
+        [0.0, 1.0, 0.0],
+        [0.0, 0.0, 1.0],
+        [1.0, 0.0, 1.0],
+        [1.0, 1.0, 1.0],
+        [0.0, 1.0, 1.0],
+    ],
     [  # Split the cube into tets and pyramids.
         (
             "polyhedron4",
@@ -282,6 +278,13 @@ polyhedron_mesh = meshio.Mesh(
             [
                 [
                     # np.asarray on this causes a numpy warning
+                    # ```
+                    # VisibleDeprecationWarning: Creating an ndarray from ragged nested
+                    # sequences (which is a list-or-tuple of lists-or-tuples-or ndarrays
+                    # with different lengths or shapes) is deprecated. If you meant to
+                    # do this, you must specify 'dtype=object' when creating the
+                    # ndarray.
+                    # ```
                     # TODO come up with a better data structure for polyhedra
                     [0, 1, 2, 3],  # pyramid base is a rectangle
                     [0, 1, 7],
@@ -359,8 +362,7 @@ def write_read(writer, reader, input_mesh, atol, extension=".dat"):
     in_mesh = copy.deepcopy(input_mesh)
 
     with tempfile.TemporaryDirectory() as temp_dir:
-        filepath = os.path.join(temp_dir, "test" + extension)
-        p = Path(filepath)
+        p = Path(temp_dir) / ("test" + extension)
         writer(p, input_mesh)
         mesh = reader(p)
 
@@ -381,20 +383,23 @@ def write_read(writer, reader, input_mesh, atol, extension=".dat"):
     # Numpy's array_equal is too strict here, cf.
     # <https://mail.scipy.org/pipermail/numpy-discussion/2015-December/074410.html>.
     # Use allclose.
-    n = in_mesh.points.shape[1]
-    assert np.allclose(in_mesh.points, mesh.points[:, :n], atol=atol, rtol=0.0)
+    if in_mesh.points.shape[0] == 0:
+        assert mesh.points.shape[0] == 0
+    else:
+        n = in_mesh.points.shape[1]
+        assert np.allclose(in_mesh.points, mesh.points[:, :n], atol=atol, rtol=0.0)
 
-    # To avoid errors from sorted (below), specify the key as first cell type
-    # then index of the first point of the first cell. This may still lead to
-    # comparison of what should be different blocks, but chances seem low.
+    # To avoid errors from sorted (below), specify the key as first cell type then index
+    # of the first point of the first cell. This may still lead to comparison of what
+    # should be different blocks, but chances seem low.
     def cell_sorter(cell):
-        if cell.type[:10] == "polyhedron":
+        if cell.type.startswith("polyhedron"):
             # Polyhedra blocks should be well enough distinguished by their type
             return cell.type
         else:
             return (cell.type, cell.data[0, 0])
 
-    # to make sure we are testing same type of cells we sort the list
+    # to make sure we are testing the same type of cells we sort the list
     for cells0, cells1 in zip(
         sorted(input_mesh.cells, key=cell_sorter), sorted(mesh.cells, key=cell_sorter)
     ):
@@ -419,8 +424,16 @@ def write_read(writer, reader, input_mesh, atol, extension=".dat"):
             # assert d0.dtype == d1.dtype, (d0.dtype, d1.dtype)
             assert np.allclose(d0, d1, atol=atol, rtol=0.0)
 
+    print()
+    print("helpers:")
+    print(input_mesh.field_data)
+    print()
+    print(mesh.field_data)
     for name, data in input_mesh.field_data.items():
-        assert np.allclose(data, mesh.field_data[name], atol=atol, rtol=0.0)
+        if isinstance(data, list):
+            assert data == mesh.field_data[name]
+        else:
+            assert np.allclose(data, mesh.field_data[name], atol=atol, rtol=0.0)
 
     # Test of cell sets (assumed to be a list of numpy arrays),
     for name, data in input_mesh.cell_sets.items():
@@ -434,7 +447,7 @@ def write_read(writer, reader, input_mesh, atol, extension=".dat"):
 
 def generic_io(filename):
     with tempfile.TemporaryDirectory() as temp_dir:
-        filepath = os.path.join(temp_dir, filename)
+        filepath = Path(temp_dir) / filename
         meshio.write_points_cells(filepath, tri_mesh.points, tri_mesh.cells)
         out_mesh = meshio.read(filepath)
         assert (abs(out_mesh.points - tri_mesh.points) < 1.0e-15).all()
