@@ -1,10 +1,16 @@
+import helpers
 import pytest
 
-import helpers
 import meshio
 
 
-@pytest.mark.parametrize("mesh", [helpers.tet_mesh])
+@pytest.mark.parametrize(
+    "mesh",
+    [
+        # helpers.empty_mesh,
+        helpers.tet_mesh
+    ],
+)
 def test(mesh):
     def writer(*args, **kwargs):
         return meshio.cgns.write(*args, **kwargs)
