@@ -3,10 +3,9 @@ from pathlib import Path
 
 import pytest
 
-import helpers
 import meshio
 
-OBJ_PATH = helpers.MESHES_DIR / "obj" / "elephav.obj"
+OBJ_PATH = Path(__file__).resolve().parent / "meshes" / "obj" / "elephav.obj"
 
 
 def test_read_str():
