@@ -8,7 +8,8 @@ import meshio
 
 
 @pytest.mark.parametrize(
-    "mesh", [helpers.tri_mesh, helpers.quad_mesh, helpers.tri_quad_mesh]
+    "mesh",
+    [helpers.empty_mesh, helpers.tri_mesh, helpers.quad_mesh, helpers.tri_quad_mesh],
 )
 def test_obj(mesh):
     def writer(*args, **kwargs):
