@@ -1,10 +1,16 @@
+import helpers
 import pytest
 
-import helpers
 import meshio
 
 
-@pytest.mark.parametrize("mesh", [helpers.tri_mesh])
+@pytest.mark.parametrize(
+    "mesh",
+    [
+        # helpers.empty_mesh,
+        helpers.tri_mesh
+    ],
+)
 def test_io(mesh):
     helpers.write_read(meshio.off.write, meshio.off.read, mesh, 1.0e-15)
 
