@@ -4,7 +4,13 @@ import pytest
 import meshio
 
 
-@pytest.mark.parametrize("mesh", [helpers.tri_mesh])
+@pytest.mark.parametrize(
+    "mesh",
+    [
+        # helpers.empty_mesh,
+        helpers.tri_mesh
+    ],
+)
 @pytest.mark.parametrize(
     "binary, tol",
     [
