@@ -1,5 +1,4 @@
 import pathlib
-import sys
 
 import helpers
 import numpy as np
@@ -10,10 +9,10 @@ import meshio
 this_dir = pathlib.Path(__file__).resolve().parent
 
 
-@pytest.mark.skipif(sys.version_info < (3, 6), reason="requires Python 3.6 or higher")
 @pytest.mark.parametrize(
     "mesh",
     [
+        helpers.empty_mesh,
         helpers.tri_mesh,
         helpers.quad_mesh,
         helpers.tri_quad_mesh,
@@ -40,7 +39,6 @@ def test_io(mesh, accuracy, ext):
     helpers.write_read(meshio.ugrid.write, meshio.ugrid.read, mesh, accuracy, ext)
 
 
-@pytest.mark.skipif(sys.version_info < (3, 6), reason="requires Python 3.6 or higher")
 def test_generic_io():
     helpers.generic_io("test.lb8.ugrid")
     # With additional, insignificant suffix:
@@ -49,7 +47,6 @@ def test_generic_io():
 
 # sphere_mixed.1.lb8.ugrid and hch_strct.4.lb8.ugrid created
 # using the codes from http://cfdbooks.com
-@pytest.mark.skipif(sys.version_info < (3, 6), reason="requires Python 3.6 or higher")
 @pytest.mark.parametrize(
     "filename, ref_num_points, ref_num_triangle, ref_num_quad, ref_num_wedge, ref_num_tet, ref_num_hex, ref_tag_counts",
     [
@@ -177,7 +174,6 @@ def _pyramid_volume(cell):
 
 # ugrid node ordering is the same for all elements except the pyramids. In order to make
 # sure we got it right read a cube split into pyramids and evaluate its volume
-@pytest.mark.skipif(sys.version_info < (3, 6), reason="requires Python 3.6 or higher")
 @pytest.mark.parametrize("filename, volume,accuracy", [("pyra_cube.ugrid", 1.0, 1e-15)])
 def test_volume(filename, volume, accuracy):
     filename = this_dir / "meshes" / "ugrid" / filename
