@@ -7,6 +7,7 @@ import pytest
 import meshio
 
 test_set = [
+    # helpers.empty_mesh,
     helpers.line_mesh,
     helpers.tri_mesh,
     helpers.triangle6_mesh,
@@ -75,4 +76,4 @@ def test_read_from_file(filename, ref_cells, ref_num_cells, ref_num_pnt):
 
 
 if __name__ == "__main__":
-    test(helpers.tet10_mesh, binary=False)
+    test(helpers.tet10_mesh, (True, None))
